@@ -347,7 +347,16 @@ void personal_photo_frame_update_content (PersonalPhotoFrame *self)
 
 	if (self->priv->singleMode) {
 		g_object_unref (self->priv->image);
-		self->priv->image = gdk_pixbuf_new_from_file_at_scale (self->priv->singleFilename, self->priv->actualSize - 10, self->priv->actualSize - 10, TRUE, NULL);
+		self->priv->image = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, self->priv->actualSize - 10, self->priv->actualSize - 10);
+		gdk_pixbuf_fill (self->priv->image, 0x00000000);
+		
+		GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_scale (self->priv->singleFilename, self->priv->actualSize - 10, self->priv->actualSize - 10, TRUE, NULL);
+		if (pixbuf) {
+			g_object_unref (self->priv->image);
+			self->priv->image = gdk_pixbuf_copy (pixbuf);
+			g_object_unref (pixbuf);
+			gtk_widget_queue_draw (self);
+		}
 	} else {
 		GDir *dir = g_dir_open (self->priv->slideshowDirname, 0, NULL);
 		
@@ -397,9 +406,16 @@ void personal_photo_from_single_photo_select (GtkWidget *button, PersonalPhotoFr
 {
 	//g_warning ("%s", __PRETTY_FUNCTION__);
 	GtkWidget *dialog = hildon_file_chooser_dialog_new (GTK_WINDOW (self->priv->settingsDialog), GTK_FILE_CHOOSER_ACTION_OPEN);
+	gtk_file_chooser_select_filename (GTK_FILE_CHOOSER (dialog), self->priv->singleFilename);
+	GtkFileFilter *filter = gtk_file_filter_new ();
+	gtk_file_filter_add_mime_type (filter, "image/*");
+	gtk_file_chooser_add_filter (dialog, filter);
+	gtk_file_chooser_set_filter (dialog, filter);
 	
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
 		gchar *filename = gtk_file_chooser_get_filename (dialog);
+		self->priv->singleFilename = g_strdup (filename);
+		filename = g_filename_display_basename (filename);
 		hildon_button_set_value (HILDON_BUTTON (button), filename);
 		g_free (filename);
 	}
@@ -410,6 +426,7 @@ void personal_photo_frame_slideshow_dir_select (GtkWidget *button, PersonalPhoto
 {
 	//g_warning ("%s", __PRETTY_FUNCTION__);
 	GtkWidget *dialog = hildon_file_chooser_dialog_new (GTK_WINDOW (self->priv->settingsDialog), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
+	gtk_file_chooser_select_filename (GTK_FILE_CHOOSER (dialog), self->priv->slideshowDirname);
 	
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
 		gchar *dirname = gtk_file_chooser_get_filename (dialog);
@@ -465,7 +482,9 @@ void personal_photo_frame_settings (HDHomePluginItem *hitem, PersonalPhotoFrame
 	
 	GtkWidget *singlePhotoButton = hildon_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
 	hildon_button_set_title (HILDON_BUTTON (singlePhotoButton), "Select photo");
-	hildon_button_set_value (HILDON_BUTTON (singlePhotoButton), self->priv->singleFilename);
+	gchar *filename = g_filename_display_basename (self->priv->singleFilename);
+	hildon_button_set_value (HILDON_BUTTON (singlePhotoButton), filename);
+	g_free (filename);
 	gtk_box_pack_start (GTK_BOX (self->priv->singleModeBox), singlePhotoButton, FALSE, FALSE, 0);
 	g_signal_connect (singlePhotoButton, "clicked", G_CALLBACK (personal_photo_from_single_photo_select), self);
 	
@@ -514,7 +533,6 @@ void personal_photo_frame_settings (HDHomePluginItem *hitem, PersonalPhotoFrame
 	if (gtk_dialog_run (GTK_DIALOG (self->priv->settingsDialog)) == GTK_RESPONSE_ACCEPT) {
 		gchar *compare = g_strdup (self->priv->slideshowDirname);
 		self->priv->singleMode = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (singleModeToggle));
-		self->priv->singleFilename = g_strdup (hildon_button_get_value (HILDON_BUTTON (singlePhotoButton)));
 		self->priv->slideshowDirname = g_strdup (hildon_button_get_value (HILDON_BUTTON (slideshowDirButton)));
 		self->priv->slideshowDuration = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (selector), 0);
 		self->priv->slideshowRandom = hildon_check_button_get_active (HILDON_CHECK_BUTTON (slideshowRandom));
